<!--报警数据分析统计-->
<template>
  <div class="alarm-data-statistics">
    <public-title title="成本分析-整体成本分析" />
    <div class="chart-container">
      <div id="overall-cost" style="width: 100%;height: 100%;" />
    </div>
  </div>
</template>

<script>
import * as echarts from 'echarts'
import api from '../api'
import PublicTitle from '../PublicTitle/index.vue'

export default {
  name: 'overallCost',
  components: { PublicTitle },
  props: {
    searchDate: {
      type: Object,
      default: () => {}
    }
  },
  watch: {
    searchDate: {
      handler(newVal,oldVal) {
        this.getChartData(newVal)
      },
      deep: true
    }
  },
  data() {
    return {
      myChart: null,  // 图表实例对象
      chartData: {}
    }
  },
  created() {
    this.getChartData()
  },
  mounted() {
    this.myChart = echarts.init(document.getElementById('overall-cost'))
  },
  methods: {
    async getChartData(data={}) {
      api.getOverallCostData(data, res => {
        this.chartData = res.state ? res.value[0] : {}
        this.chartData.total = (this.chartData.cgPrice || 0) + (this.chartData.ckPrice || 0) + (this.chartData.kcPrice || 0)
        this.$nextTick(_ => this.initEcharts())
      })
    },

    // 初始化图表
    initEcharts() {
      this.myChart.setOption({
        color: ['#48D1CC', '#3eadfd', '#F4A460'],
        tooltip: {
          trigger: 'item',
          textStyle: {
            fontSize: 14,
            color: '#606266'
          }
        },
        graphic: [{
          type: 'group',
          left: '50%',
          top: '57%',
          bounding: 'raw',
          children: [{
            type: 'text',
            style: {
              text: `总计\n${this.chartData?.total || 0}元`,
              fontSize: 17,
              lineHeight: 28,
              fill: '#36d9c6',
              textVerticalAlign: 'middle',
              textAlign: 'center'
            }
          }]
        }],
        legend: {
          position: 'center',
          top: 0,
          textStyle: {
            fontSize: 14,
            color: '#606266'
          }
        },
        series: [
          {
            name: '整体成本分析',
            type: 'pie',
            clockwise: false,
            startAngle: 90,
            radius: ['50%', '80%'],
            center: ['50%', '57%'],
            avoidLabelOverlap: false,
            itemStyle: {
              // borderRadius: 10,
              borderColor: 'rgba(255,255,255,0)',
              borderWidth: 3
            },
            data: [
              {
                value: this.chartData?.cgPrice || 0,
                name: '采购金额'
              },
              {
                value: this.chartData?.kcPrice || 0,
                name: '库存金额'
              },
              {
                value: this.chartData?.ckPrice || 0,
                name: '领用金额'
              }
            ],
            label: {
              normal: {
                show: true,
                position: 'outside',
                formatter: ({percent, value, name}) => {
                  // (percent ? percent.toFixed(0) + '%' : '')
                  return name +'\n' + value + '元'
                },
                textStyle: {
                  align: 'center',
                  fontSize: 14,
                  // fontWeight: 'bolder',
                  color: '#606266'
                }
              }
            }
          },
          {
            name: '整体成本分析',
            type: 'pie',
            clockwise: false,
            startAngle: 90,
            radius: ['50%', '80%'],
            center: ['50%', '57%'],
            avoidLabelOverlap: false,
            itemStyle: {
              // borderRadius: 10,
              borderColor: 'rgba(255,255,255,0)',
              borderWidth: 3
            },
            data: [
              {
                value: this.chartData?.cgPrice || 0,
                name: '采购金额'
              },
              {
                value: this.chartData?.kcPrice || 0,
                name: '库存金额'
              },
              {
                value: this.chartData?.ckPrice || 0,
                name: '领用金额'
              }
            ],
            label: {
              normal: {
                show: true,
                position: 'inside',
                formatter: ({percent, value, name}) => { 
                  return (percent ? percent.toFixed(0) + '%' : '')
                },
                textStyle: {
                  align: 'center',
                  fontSize: 14,
                  fontWeight: 'bolder',
                  color: '#fff'
                }
              }
            }
          }
        ]
      })
      //随着屏幕大小调节图表
      window.addEventListener('resize', _ => this.myChart.resize())
    }
  },
  beforeDestroy() {
    // 取消事件的监听
    window.removeEventListener('resize', _ => this.myChart.resize())
  }
}
</script>

<style lang="scss" scoped>
.alarm-data-statistics {
  width: 100%;
  height: 100%;
  display: flex;
  flex-direction: column;

  .chart-container {
    flex: 1;
    width: 100%;
    box-sizing: border-box;
    padding: 15px 20px;
  }
}
</style>